docs.rs failed to build vtcode-acp-0.136.4
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
vtcode-acp-0.128.4
vtcode-acp
vtcode-acp is the canonical ACP crate for VT Code.
It contains:
- The ACP client library now lives in this crate
- The VT Code Zed bridge and ACP connection registration helpers
ACP (Agent Communication Protocol) support for VT Code.
This crate exposes both the ACP client library and the VT Code Zed bridge. Downstream crates should treat this as the canonical ACP entrypoint.
Public entrypoints
AcpClientV2for protocol-compliant ACP clientsAcpClientfor the deprecated V1 client APIStandardAcpAdapterandZedAcpAdapterfor launching VT Code over ACP
API reference
See docs.rs/vtcode-acp.