JsonRpcError

Struct JsonRpcError 

pub struct JsonRpcError {
    pub code: i32,
    pub message: String,
    pub data: Option<Value>,
}
JSON-RPC 2.0 error object

Fields

code: i32

Error code (integer)

message: String

Short error description

data: Option<Value>

Additional error data

Implementations

Source

impl JsonRpcError

pub fn new(code: i32, message: impl Into<String>) -> Self

Create a new error

pub fn with_data(code: i32, message: impl Into<String>, data: Value) -> Self

Create error with additional data

pub fn parse_error(details: impl Into<String>) -> Self

Create a parse error

pub fn invalid_request(details: impl Into<String>) -> Self

Create an invalid request error

pub fn method_not_found(method: impl Into<String>) -> Self

Create a method not found error

pub fn invalid_params(details: impl Into<String>) -> Self

Create an invalid params error

pub fn internal_error(details: impl Into<String>) -> Self

Create an internal error

pub fn auth_required(auth_methods: Vec<AuthMethod>) -> Self

Create an authentication required error with list of available methods

Per ACP spec, includes authMethods in error data to help clients present appropriate UI for authentication options.

pub fn permission_denied(details: impl Into<String>) -> Self

Create a permission denied error

pub fn session_not_found(session_id: impl Into<String>) -> Self

Create a session not found error

pub fn rate_limited(details: impl Into<String>) -> Self

Create a rate limited error

pub fn resource_not_found(resource: impl Into<String>) -> Self

Create a resource not found error